@@ -1,13 +1,15 @@
+#
+# vim:set ff=unix expandtab ts=2 sw=2:
 GeneralModel=structure(function #The most general costructor for class Model
 ### The function creates a numerical model  for n arbitrarily connected pools.
 ### It is one of the constructors of class Model                       
-### It is e.g. used by some more specialized wrapper functions like for instance \code{\link{ParallelModel}} but can also be used directly. It is in fact the most### versatile interface to produce instances of class Model. 
+### It is e.g. used by some more specialized wrapper functions like for instance \code{\link{ParallelModel}} but can also be used directly. It is in fact the most versatile interface to produce instances of class Model. 
 
 (t,			##<< A vector containing the points in time where the solution is sought.
  A,			##<< A TimeMap object consisting of  a matrix valued function describing the whole model decay rates for the n pools, connection and feedback coefficients as functions of time and a time range for which this function is valid. The size of the quadtratic matric must be equal to the number of pools. The time range must cover the times given in the first argument. 
- ivList,		##<< A vector containing the initial amount of carbon for the n pools. The length of this vector is equal to the number of pools and thus equal to the length of k. This is checked by the function \code{\link{correctnessOfModel}}.
+ ivList,		##<< A vector containing the initial amount of carbon for the n pools. The length of this vector is equal to the number of pools and thus equal to the length of k. This is checked by an internal  function. 
  inputFluxes, ##<< A TimeMap object consisting of a vector valued function describing the inputs to the pools as funtions of time \code{\link{TimeMap.new}}.
- solverfunc=deSolve.lsoda.wrapper,		##<< The function used by to actually solve the ODE system. This can be \code{\link{SoilR.euler}} or \code{\link{deSolve.lsoda.wrapper}} or any other user provided function with the same interface. 
+ solverfunc=deSolve.lsoda.wrapper,		##<< The function used by to actually solve the ODE system. This can be \code{\link{deSolve.lsoda.wrapper}} or any other user provided function with the same interface. 
  pass=FALSE  ##<< Forces the constructor to create the model even if it is invalid 
  )
 {
@@ -15,7 +17,7 @@ GeneralModel=structure(function #The most general costructor for class Model
    obj=new(Class="Model",t,A,ivList,inputFluxes,solverfunc,pass)
    return(obj)
    ### A model object that can be further queried. 
-   ##seealso<< \code{\link{TwopParallelModel}} 
+   ##seealso<< \code{\link{TwopParallelModel}}, \code{\link{TwopSeriesModel}}, \code{\link{TwopFeedbackModel}} 
 }
 ,ex=function(){
       t_start=0 
