@@ -1,3 +1,5 @@
+#
+# vim:set ff=unix expandtab ts=2 sw=2:
 ThreepParallelModel14<-structure(
   function #Implementation of a three-pool C14 model with parallel structure
   ### This function creates a model for two independent (parallel) pools. 
@@ -5,14 +7,16 @@ ThreepParallelModel14<-structure(
   (t,  		##<< A vector containing the points in time where the solution is sought. It must be specified within the same period for which the Delta 14 C of the atmosphere is provided. The default period in the provided dataset \code{\link{C14Atm_NH}} is 1900-2010.
    ks,	##<< A vector of length 3 containing the decomposition rates for the 3 pools. 
    C0,	##<< A vector of length 3 containing the initial amount of carbon for the 3 pools.
+   F0_Delta14C,  ##<< A vector of length 3 containing the initial amount of the radiocarbon fraction for the 3 pools in  Delta14C values in per mil.
    In,     ##<< A scalar or a data.frame object specifying the amount of litter inputs by time.
    gam1,  ##<< A scalar representing the partitioning coefficient, i.e. the proportion from the total amount of inputs that goes to pool 1.
    gam2,  ##<< A scalar representing the partitioning coefficient, i.e. the proportion from the total amount of inputs that goes to pool 2.
    xi=1,   ##<< A scalar or a data.frame specifying the external (environmental and/or edaphic) effects on decomposition rates. 
-   FcAtm,##<< A Data Frame object consisting of  a function describing the fraction of C_14 in per mille.
+   FcAtm,##<< A Data Frame object containing values of atmospheric Delta14C per time. First column must be time values, second column must be Delta14C values in per mil.
    lambda=-0.0001209681, ##<< Radioactive decay constant. By default lambda=-0.0001209681 y^-1 . This has the side effect that all your time related data are treated as if the time unit was year.
    lag=0, ##<< A positive scalar representing a time lag for radiocarbon to enter the system. 
-   solver=deSolve.lsoda.wrapper ##<< A function that solves the system of ODEs. This can be \code{\link{euler}} or \code{\link{ode}} or any other user provided function with the same interface.
+   solver=deSolve.lsoda.wrapper, ##<< A function that solves the system of ODEs. This can be \code{\link{euler}} or \code{\link{ode}} or any other user provided function with the same interface.
+   pass=FALSE  ##<< if TRUE Forces the constructor to create the model even if it is invalid 
    )	
   { 
     t_start=min(t)
@@ -54,36 +58,58 @@ ThreepParallelModel14<-structure(
            }
            ) 
     
-    Fc=TimeMap.from.Dataframe(FcAtm,lag)
+    Fc=FcAtm.from.Dataframe(FcAtm,lag,format="Delta14C")
     
-    mod=GeneralModel_14(t,At,ivList=C0,inputFluxes=inputrates,Fc,di=lambda)
+    mod=GeneralModel_14(t,At,ivList=C0,initialValF=SoilR.F0.new(F0_Delta14C,"Delta14C"),
+                        inputFluxes=inputrates,Fc,di=lambda,pass=pass)
     ### A Model Object that can be further queried 
     ##seealso<< \code{\link{TwopSeriesModel14}}, \code{\link{TwopFeedbackModel14}}  
   }
   ,
   ex=function(){
     
-    data(C14Atm_NH)
-    #Fc=TimeMap.from.Dataframe(C14Atm_NH)
     years=seq(1901,2009,by=0.5)
     LitterInput=700 
     
-    Ex=ThreepParallelModel14(t=years,ks=c(k1=1/2.8, k2=1/35, k3=1/100),C0=c(200,5000,500), In=LitterInput, gam1=0.7, gam2=0.1, FcAtm=C14Atm_NH,lag=2)
-    R14m=getTotalReleaseFluxC14CRatio(Ex)
-    C14m=getTotalC14CRatio(Ex)
-    C14t=getSoilC14Fraction(Ex)
+    Ex=ThreepParallelModel14(
+      t=years,
+      ks=c(k1=1/2.8, k2=1/35, k3=1/100),
+      C0=c(200,5000,500),
+      F0_Delta14C=c(0,0,0),
+      In=LitterInput,
+      gam1=0.7,
+      gam2=0.1,
+      FcAtm=C14Atm_NH,
+      lag=2
+    )
+    R14m=getF14R(Ex)
+    C14m=getF14C(Ex)
+    C14t=getF14(Ex)
     
     par(mfrow=c(2,1))
     plot(C14Atm_NH,type="l",xlab="Year",ylab="Delta 14C (per mil)",xlim=c(1940,2010)) 
     lines(years, C14t[,1], col=4)
     lines(years, C14t[,2],col=4,lwd=2)
     lines(years, C14t[,3],col=4,lwd=3)
-    legend("topright",c("Delta 14C Atmosphere", "Delta 14C pool 1", "Delta 14C pool 2", "Delta 14C pool 3"),lty=rep(1,4),col=c(1,4,4,4),lwd=c(1,1,2,3),bty="n")
+    legend(
+      "topright",
+      c(
+        "Delta 14C Atmosphere", 
+        "Delta 14C pool 1",
+        "Delta 14C pool 2", 
+        "Delta 14C pool 3"
+      ),
+      lty=rep(1,4),
+      col=c(1,4,4,4),
+      lwd=c(1,1,2,3),
+      bty="n"
+    )
     
     plot(C14Atm_NH,type="l",xlab="Year",ylab="Delta 14C (per mil)",xlim=c(1940,2010)) 
     lines(years,C14m,col=4)
     lines(years,R14m,col=2)
-    legend("topright",c("Delta 14C Atmosphere","Delta 14C SOM", "Delta 14C Respired"),lty=c(1,1,1), col=c(1,4,2),bty="n")
+    legend("topright",c("Delta 14C Atmosphere","Delta 14C SOM", "Delta 14C Respired"),
+           lty=c(1,1,1), col=c(1,4,2),bty="n")
     par(mfrow=c(1,1))
   }
   )
