@@ -1,3 +1,5 @@
+#
+# vim:set ff=unix expandtab ts=2 sw=2:
 ThreepSeriesModel<-structure(
     function #Implementation of a three pool model with series structure
     ### This function creates a model for three pools connected in series. It is a wrapper for the more general function \code{\link{GeneralModel}}.
@@ -29,8 +31,8 @@ ThreepSeriesModel<-structure(
          y=In[,2]  
          inputFlux=splinefun(x,y)
           inputFluxes=TimeMap.new(
-            t_start,
-            t_end,
+            min(x),
+            max(x),
             function(t){matrix(nrow=3,ncol=1,c(inputFlux(t),0,0))}
           )
         }
@@ -50,7 +52,7 @@ ThreepSeriesModel<-structure(
             t_end,
             function(t){fX(t)*A}
       )
-      Mod=GeneralModel(t=t,A=Af,ivList=C0,inputFluxes=inputFluxes)
+      Mod=GeneralModel(t=t,A=Af,ivList=C0,inputFluxes=inputFluxes,pass=pass)
      return(Mod)
 ### A Model Object that can be further queried 
       ##seealso<< \code{\link{ThreepParallelModel}}, \code{\link{ThreepFeedbackModel}} 
@@ -70,17 +72,22 @@ ThreepSeriesModel<-structure(
       Ct=getC(Ex1)
       Rt=getReleaseFlux(Ex1)
       
-      plot(t,rowSums(Ct),type="l",ylab="Carbon stocks (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ct[1,]))) 
+      plot(t,rowSums(Ct),type="l",ylab="Carbon stocks (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ct[1,]))) 
       lines(t,Ct[,1],col=2)
       lines(t,Ct[,2],col=4)
       lines(t,Ct[,3],col=3)
-      legend("topright",c("Total C","C in pool 1", "C in pool 2","C in pool 3"),lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
+      legend("topright",c("Total C","C in pool 1", "C in pool 2","C in pool 3"),
+             lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
 
-      plot(t,rowSums(Rt),type="l",ylab="Carbon released (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rt[1,]))) 
+      plot(t,rowSums(Rt),type="l",ylab="Carbon released (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rt[1,]))) 
       lines(t,Rt[,1],col=2)
       lines(t,Rt[,2],col=4)
       lines(t,Rt[,3],col=3)
-      legend("topright",c("Total C release","C release from pool 1", "C release from pool 2","C release from pool 3"),lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
+      legend("topright",c("Total C release","C release from pool 1",
+                          "C release from pool 2","C release from pool 3"),
+             lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
       
       Inr=data.frame(t,Random.inputs=rnorm(length(t),50,10))
       plot(Inr,type="l")
@@ -89,16 +96,21 @@ ThreepSeriesModel<-structure(
       Ctr=getC(Ex2)
       Rtr=getReleaseFlux(Ex2)
       
-      plot(t,rowSums(Ctr),type="l",ylab="Carbon stocks (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ctr[1,]))) 
+      plot(t,rowSums(Ctr),type="l",ylab="Carbon stocks (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ctr[1,]))) 
       lines(t,Ctr[,1],col=2)
       lines(t,Ctr[,2],col=4)
       lines(t,Ctr[,3],col=3)
-      legend("topright",c("Total C","C in pool 1", "C in pool 2","C in pool 3"),lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
+      legend("topright",c("Total C","C in pool 1", "C in pool 2","C in pool 3"),
+             lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
 
-      plot(t,rowSums(Rtr),type="l",ylab="Carbon released (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rtr[1,]))) 
+      plot(t,rowSums(Rtr),type="l",ylab="Carbon released (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rtr[1,]))) 
       lines(t,Rtr[,1],col=2)
       lines(t,Rtr[,2],col=4)
       lines(t,Rtr[,3],col=3)
-      legend("topright",c("Total C release","C release from pool 1", "C release from pool 2","C release from pool 3"),lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
+      legend("topright",c("Total C release","C release from pool 1",
+                          "C release from pool 2","C release from pool 3"),
+             lty=c(1,1,1,1),col=c(1,2,4,3),lwd=c(2,1,1,1),bty="n")
 }
 )
