@@ -1,3 +1,5 @@
+#
+# vim:set ff=unix expandtab ts=2 sw=2:
 TwopSeriesModel<-structure(
     function #Implementation of a two pool model with series structure
     ### This function creates a model for two pools connected in series. It is a wrapper for the more general function \code{\link{GeneralModel}}.
@@ -28,8 +30,8 @@ TwopSeriesModel<-structure(
          y=In[,2]  
          inputFlux=splinefun(x,y)
           inputFluxes=TimeMap.new(
-            t_start,
-            t_end,
+            min(x),
+            max(x),
             function(t){matrix(nrow=2,ncol=1,c(inputFlux(t),0))}
           )
         }
@@ -47,7 +49,7 @@ TwopSeriesModel<-structure(
         t_end,
         function(t){fX(t)*A}
       )
-      Mod=GeneralModel(t=t,A=Af,ivList=C0,inputFluxes=inputFluxes)
+      Mod=GeneralModel(t=t,A=Af,ivList=C0,inputFluxes=inputFluxes,pass=pass)
      return(Mod)
 ### A Model Object that can be further queried 
       ##seealso<< \code{\link{TwopParallelModel}},\code{\link{TwopFeedbackModel}} 
@@ -71,15 +73,19 @@ TwopSeriesModel<-structure(
       Ct=getC(Ex1)
       Rt=getReleaseFlux(Ex1)
       
-      plot(t,rowSums(Ct),type="l",ylab="Carbon stocks (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ct[1,]))) 
+      plot(t,rowSums(Ct),type="l",ylab="Carbon stocks (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ct[1,]))) 
       lines(t,Ct[,1],col=2)
       lines(t,Ct[,2],col=4) 
-      legend("bottomright",c("Total C","C in pool 1", "C in pool 2"),lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
+      legend("bottomright",c("Total C","C in pool 1", "C in pool 2"),
+             lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
 
-      plot(t,rowSums(Rt),type="l",ylab="Carbon released (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rt[1,]))) 
+      plot(t,rowSums(Rt),type="l",ylab="Carbon released (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rt[1,]))) 
       lines(t,Rt[,1],col=2)
       lines(t,Rt[,2],col=4) 
-      legend("topright",c("Total C release","C release from pool 1", "C release from pool 2"),lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
+      legend("topright",c("Total C release","C release from pool 1", "C release from pool 2"),
+             lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
       
       Inr=data.frame(t,Random.inputs=rnorm(length(t),30,5))
       plot(Inr)
@@ -88,14 +94,18 @@ TwopSeriesModel<-structure(
       Ctr=getC(Ex2)
       Rtr=getReleaseFlux(Ex2)
       
-      plot(t,rowSums(Ctr),type="l",ylab="Carbon stocks (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ctr[1,]))) 
+      plot(t,rowSums(Ctr),type="l",ylab="Carbon stocks (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Ctr[1,]))) 
       lines(t,Ctr[,1],col=2)
       lines(t,Ctr[,2],col=4) 
-      legend("topright",c("Total C","C in pool 1", "C in pool 2"),lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
+      legend("topright",c("Total C","C in pool 1", "C in pool 2"),
+             lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
 
-      plot(t,rowSums(Rtr),type="l",ylab="Carbon released (arbitrary units)",xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rtr[1,]))) 
+      plot(t,rowSums(Rtr),type="l",ylab="Carbon released (arbitrary units)",
+           xlab="Time (arbitrary units)",lwd=2,ylim=c(0,sum(Rtr[1,]))) 
       lines(t,Rtr[,1],col=2)
       lines(t,Rtr[,2],col=4) 
-      legend("topright",c("Total C release","C release from pool 1", "C release from pool 2"),lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
+      legend("topright",c("Total C release","C release from pool 1", "C release from pool 2"),
+             lty=c(1,1,1),col=c(1,2,4),lwd=c(2,1,1),bty="n")
 }
 )
